@@ -403,10 +403,8 @@ void LiquidStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
               w->setPalette( pal );
            }
             else
-#if !KDE_IS_VERSION(3,4,3)
-	    if (!(w->parent() && w->parent()->inherits("MiniBar")))
-#endif
-                w->setBackgroundMode( TQWidget::NoBackground);
+            w->setBackgroundMode( TQWidget::NoBackground);
+
             installObjectEventHandler(ceData, elementFlags, ptr, this);
             goto kstpolish;
         }
